package com.bonus.material.warehouse.service;

import java.util.List;
import com.bonus.material.warehouse.domain.WhHouseSet;

/**
 * 仓库货架配置Service接口
 * 
 * @author xsheng
 * @date 2024-09-27
 */
public interface IWhHouseSetService 
{
    /**
     * 查询仓库货架配置
     * 
     * @param id 仓库货架配置主键
     * @return 仓库货架配置
     */
    public WhHouseSet selectWhHouseSetById(Long id);

    /**
     * 查询仓库货架配置列表
     * 
     * @param whHouseSet 仓库货架配置
     * @return 仓库货架配置集合
     */
    public List<WhHouseSet> selectWhHouseSetList(WhHouseSet whHouseSet);

    List<WhHouseSet> selectListByMaType(Long typeId);

    /**
     * 新增仓库货架配置
     * 
     * @param whHouseSet 仓库货架配置
     * @return 结果
     */
    public int insertWhHouseSet(WhHouseSet whHouseSet);

    /**
     * 修改仓库货架配置
     * 
     * @param whHouseSet 仓库货架配置
     * @return 结果
     */
    public int updateWhHouseSet(WhHouseSet whHouseSet);

    /**
     * 批量删除仓库货架配置
     * 
     * @param ids 需要删除的仓库货架配置主键集合
     * @return 结果
     */
    public int deleteWhHouseSetByIds(Long[] ids);

    /**
     * 删除仓库货架配置信息
     * 
     * @param id 仓库货架配置主键
     * @return 结果
     */
    public int deleteWhHouseSetById(Long id);
}
