package com.bonus.material.warehouse.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.warehouse.domain.WhHouseSet;
import com.bonus.material.warehouse.service.IWhHouseSetService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 仓库货架配置Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "仓库货架配置接口")
@RestController
@RequestMapping("/wh_house_set")
public class WhHouseSetController extends BaseController {

    @Autowired
    private IWhHouseSetService whHouseSetService;

    /**
     * 查询仓库货架配置列表
     */
    @ApiOperation(value = "查询仓库货架配置列表")
    @RequiresPermissions("warehouse:set:list")
    @GetMapping("/list")
    public TableDataInfo list(WhHouseSet whHouseSet)
    {
        startPage();
        List<WhHouseSet> list = whHouseSetService.selectWhHouseSetList(whHouseSet);
        return getDataTable(list);
    }

    /**
     * 导出仓库货架配置列表
     */
    @ApiOperation(value = "导出仓库货架配置列表")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:set:export")
    @SysLog(title = "仓库货架配置", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出仓库货架配置")
    @PostMapping("/export")
    public void export(HttpServletResponse response, WhHouseSet whHouseSet)
    {
        List<WhHouseSet> list = whHouseSetService.selectWhHouseSetList(whHouseSet);
        ExcelUtil<WhHouseSet> util = new ExcelUtil<WhHouseSet>(WhHouseSet.class);
        util.exportExcel(response, list, "仓库货架配置数据");
    }

    /**
     * 获取仓库货架配置详细信息
     */
    @ApiOperation(value = "获取仓库货架配置详细信息")
    @RequiresPermissions("warehouse:set:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(whHouseSetService.selectWhHouseSetById(id));
    }

    /**
     * 新增仓库货架配置
     */
    @ApiOperation(value = "新增仓库货架配置")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:set:add")
    @SysLog(title = "仓库货架配置", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增仓库货架配置")
    @PostMapping
    public AjaxResult add(@RequestBody WhHouseSet whHouseSet)
    {
        return toAjax(whHouseSetService.insertWhHouseSet(whHouseSet));
    }

    /**
     * 修改仓库货架配置
     */
    @ApiOperation(value = "修改仓库货架配置")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:set:edit")
    @SysLog(title = "仓库货架配置", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改仓库货架配置")
    @PutMapping
    public AjaxResult edit(@RequestBody WhHouseSet whHouseSet)
    {
        return toAjax(whHouseSetService.updateWhHouseSet(whHouseSet));
    }

    /**
     * 删除仓库货架配置
     */
    @ApiOperation(value = "删除仓库货架配置")
    @PreventRepeatSubmit
    @RequiresPermissions("warehouse:set:remove")
    @SysLog(title = "仓库货架配置", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除仓库货架配置")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(whHouseSetService.deleteWhHouseSetByIds(ids));
    }
}
